"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _template = _interopRequireDefault(require("./template"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Class that can parse configuration with default values.
 */
class Config {
  /**
   * Loads configuration with default values
   * @param {Object} [userConfig] Overrides for default config
   */
  static load(userConfig) {
    let config = {};

    if (typeof userConfig === 'string') {
      userConfig = require(path.join(process.cwd(), userConfig));
    }

    Object.keys(_template.default).forEach(key => config[key] = _template.default[key].value);
    Object.assign(config, userConfig);

    if (config.previewMode) {
      Config._setPreviewMode(config);
    }

    return config;
  }
  /**
   * Overrides preview mode configurations
   * @param {Object} config
   */


  static _setPreviewMode(config) {
    Object.assign(config, {
      parallelInstances: 1,
      randomScenariosDisabled: true,
      minifyUserDefinedScenarios: false,
      headlessModeDisabled: true
    });
  }

}

exports.default = Config;